@@ -21,7 +21,7 @@ from ctapipe.coordinates import (
 from ctapipe.image import neg_log_likelihood, mean_poisson_likelihood_gaussian
 from ctapipe.instrument import get_atmosphere_profile_functions
 from ctapipe.containers import (
-    ReconstructedShowerContainer,
+    ReconstructedGeometryContainer,
     ReconstructedEnergyContainer,
 )
 from ctapipe.reco.reco_algorithms import Reconstructor
@@ -191,14 +191,6 @@ class ImPACTReconstructor(Reconstructor):
         in an event which will be used later in the Xmax calculation. Peak is
         found by taking the average position of the n hottest pixels in the
         image.
-
-        Parameters
-        ----------
-
-        Returns
-        -------
-            None
-
         """
         peak_x = np.zeros([len(self.pixel_x)])  # Create blank arrays for peaks
         # rather than a dict (faster)
@@ -404,7 +396,6 @@ class ImPACTReconstructor(Reconstructor):
         # and ignore them from then on
 
         zenith = (np.pi / 2) - self.array_direction.alt.to(u.rad).value
-        azimuth = self.array_direction.az
 
         # Geometrically calculate the depth of maximum given this test position
         x_max = self.get_shower_max(source_x, source_y, core_x, core_y, zenith)
@@ -725,7 +716,7 @@ class ImPACTReconstructor(Reconstructor):
         )
 
         # Create a container class for reconstructed shower
-        shower_result = ReconstructedShowerContainer()
+        shower_result = ReconstructedGeometryContainer()
 
         # Convert the best fits direction and core to Horizon and ground systems and
         # copy to the shower container
@@ -834,7 +825,7 @@ class ImPACTReconstructor(Reconstructor):
             self.min.tol *= 1000
             self.min.set_strategy(1)
 
-            migrad = self.min.migrad()
+            self.min.migrad()
             fit_params = self.min.values
             errors = self.min.errors
 
