@@ -1,18 +1,19 @@
 from tqdm.auto import tqdm
 import numpy as np
 from astropy.coordinates import SkyCoord
-from ctapipe.containers import TelEventIndexContainer
 
-from ctapipe.calib import CameraCalibrator
-from ctapipe.core import Provenance
-from ctapipe.core import Tool, ToolConfigurationError
-from ctapipe.core import traits
-from ctapipe.io import EventSource
-from ctapipe.io import HDF5TableWriter
-from ctapipe.image.cleaning import TailcutsImageCleaner
-from ctapipe.coordinates import TelescopeFrame, CameraFrame
-from ctapipe.containers import MuonParametersContainer
-from ctapipe.instrument import CameraGeometry
+from ..containers import TelEventIndexContainer
+from ..calib import CameraCalibrator
+from ..core import Provenance
+from ..core import Tool, ToolConfigurationError
+from ..core import traits
+from ..core.traits import flag
+from ..io import EventSource
+from ..io import HDF5TableWriter
+from ..image.cleaning import TailcutsImageCleaner
+from ..coordinates import TelescopeFrame, CameraFrame
+from ..containers import MuonParametersContainer
+from ..instrument import CameraGeometry
 
 from ctapipe.image.muon import (
     MuonRingFitter,
@@ -77,16 +78,20 @@ class MuonAnalysis(Tool):
     ]
 
     aliases = {
-        "i": "EventSource.input_url",
-        "input": "EventSource.input_url",
-        "o": "MuonAnalysis.output",
-        "output": "MuonAnalysis.output",
-        "max-events": "EventSource.max_events",
-        "allowed-tels": "EventSource.allowed_tels",
+        ("i", "input"): "EventSource.input_url",
+        ("o", "output"): "MuonAnalysis.output",
+        ("m", "max-events"): "EventSource.max_events",
+        ("t", "allowed-tels"): "EventSource.allowed_tels",
     }
 
     flags = {
-        "overwrite": ({"MuonAnalysis": {"overwrite": True}}, "overwrite output file")
+        "f": ({"MuonAnalysis": {"overwrite": True}}, "Overwrite output file"),
+        **flag(
+            "overwrite",
+            "MuonAnalysis.overwrite",
+            "Overwrite output file",
+            "Don't overwrite output file",
+        ),
     }
 
     def setup(self):
